@@ -81,7 +81,7 @@ class RDBService:
     sort : 'order by ${fields} ${asc|desc}
     page_site: 分页大小 
     """
-    def find(self, table, query, sort, fields):
+    def find(self, table, query, sort, fields,limit=None):
         raise (NameError, "Unsupported")
 
     """
@@ -184,7 +184,7 @@ class MssqlService(RDBService):
             if fields is not None:
                 s=','.join(fields)
 
-            sql = 'select top 1 {} from {} {} {}'.format(s,table, query,sort)
+            sql = 'select top 1 {} from {} {} {}'.format(s,table, query if query is not None else '', sort if sort is not None else '')
             cusor = self.conn.cursor()
             if not cusor:
                 raise (NameError, "连接数据库失败")
@@ -204,13 +204,14 @@ class MssqlService(RDBService):
     sort : 'order by ${fields} ${asc|desc}
     page_size: 分页大小
     """
-    def find(self, table, query, sort, fields):
+    def find(self, table, query, sort, fields,limit=None):
         try:
             self.__connect()
+            topN = '' if limit is None else 'top {}'.format(limit)
             if fields is None:
-                sql = 'select  * from {} {} {}'.format(table, query, sort)
+                sql = 'select {} * from {} {} {}'.format(topN,table, query if query is not None else '', sort if sort is not None else '')
             else:
-                sql = 'select {} from {} {} {}'.format(','.join(fields), table, query, sort)
+                sql = 'select {} {} from {} {} {}'.format(topN,','.join(fields), table,query if query is not None else '', sort if sort is not None else '')
             cusor = self.conn.cursor()
             if not cusor:
                 raise (NameError, "连接数据库失败")
@@ -249,7 +250,7 @@ class MysqlService(RDBService):
             if fields is not None:
                 s=','.join(fields)
 
-            sql = 'select {} from {} {} {} limit 1'.format(s,table, query,sort)
+            sql = 'select {} from {} {} {} limit 1'.format(s,table, query if query is not None else '', sort if sort is not None else '')
             cusor = self.conn.cursor()
             res = cusor.execute(sql)
             res = cusor.fetchall()
@@ -266,13 +267,15 @@ class MysqlService(RDBService):
     sort : 'order by ${fields} ${asc|desc}
     page_site: 分页大小 
     """
-    def find(self,table,query,sort,fields):
+    def find(self,table,query,sort,fields,limit=None):
         try:
             self.__connect()
+
+            topN = '' if limit is None else 'limit {}'.format(limit)
             if fields is None:
-                sql = 'select  * from {} {} {}'.format(table, query, sort)
+                sql = 'select  * from {} {} {} {}'.format(table,query if query is not None else '', sort if sort is not None else '',topN)
             else:
-                sql = 'select {} from {} {} {}'.format(','.join(fields), table, query, sort)
+                sql = 'select {} from {} {} {} {}'.format(','.join(fields), table, query if query is not None else '', sort if sort is not None else '',topN)
             cusor = self.conn.cursor()
             result = cusor.execute(sql)
             result = cusor.fetchall()
@@ -285,7 +288,7 @@ class MysqlService(RDBService):
             logging.warnning('while excute find sql with query({}) in {}'.format(table,query))
             raise e
 
-class PostgresqlService(RDBService):
+class PostgresqlService(MysqlService):
     def __init__(self,settings):
         super().__init__(settings)
 
@@ -295,56 +298,6 @@ class PostgresqlService(RDBService):
 
     def __close(self):
         super().close()
-    #根据${query}查找多条记录
-    """
-    query = "where a=b or (c like 'd')" sql子句
-    sort : 'order by ${fields} ${asc|desc}
-    page_site: 分页大小 
-    """
-    def find(self,table,query,sort,fields):
-        try:
-            self.__connect()
-            if fields is None:
-                sql = 'select  * from {} {} {}'.format(table, query, sort)
-            else:
-                sql = 'select {} from {} {} {}'.format(','.join(fields), table, query, sort)
-            cusor = self.conn.cursor()
-            result = cusor.execute(sql)
-            result = cusor.fetchall()
-            cusor.close()
-
-            # return {'total': count,'result': result}
-            return result
-        except Exception as e:
-            self.__close()
-            logging.warnning('while excute find sql with query({}) in {}'.format(table,query))
-            raise e
-
-
-
-
-    # 根据${query}查找一条记录
-    """
-    query = "where a=b or (c like 'd')" sql子句
-    """
-    def find_one(self, table, query,sort=None,fields=None):
-        try:
-            self.__connect()
-            s='*'
-
-            if fields is not None:
-                s=','.join(fields)
-
-            sql = 'select {} from {} {} {} limit 1'.format(s,table, query,sort)
-            cusor = self.conn.cursor()
-            res = cusor.execute(sql)
-            res = cusor.fetchall()
-            cusor.close()
-            return res[0] if len(res) > 0 else None
-        except Exception as e:
-            self.__close()
-            logging.warnning('while excute find_one sql with query({}) in {}'.format(table,query))
-            raise e
 
 
 
